@@ -1,18 +1,18 @@
 /*!
 
-Using the `#[sabi(kind(WithNonExhaustive(...)))]` helper attribute for 
+Using the `#[sabi(kind(WithNonExhaustive(...)))]` helper attribute for
 `#[derive(StableAbi)]` allows you to store the enum
 in `NonExhaustive`,
 using it as a non-exhaustive enum across ffi.
 
-The enum can then be wrapped in a 
+The enum can then be wrapped in a
 [`NonExhaustive<>`](../../nonexhaustive_enum/struct.NonExhaustive.html),
 but can only be converted back into it if the discriminant is valid in that context.
 
 Nonexhaustive enums can safely add variants in minor versions,
 giving library authors some flexibility in their design.
 
-# Items 
+# Items
 
 These are the items relevant to nonexhaustive enums:
 
@@ -39,7 +39,7 @@ and usable with it afterwards
 
 # Parameters
 
-These are the required and optional parameters for the 
+These are the required and optional parameters for the
 `#[sabi(kind(WithNonExhaustive(...)))]` helper attribute.
 
 ### Specifying alignment (optional parameter)
@@ -71,7 +71,7 @@ It is a bad idea to use `Enum` since its size is allowed to change.<br>
 
 ### Traits (optional parameter)
 
-Specifies the traits required when constructing NonExhaustive from this enum and 
+Specifies the traits required when constructing NonExhaustive from this enum and
 usable after constructing it.
 
 If neither this parameter nor interface are specified,
@@ -116,7 +116,7 @@ These are the valid traits:
 
 ### Interface (optional parameter)
 
-This allows using a pre-existing to specify which traits are 
+This allows using a pre-existing to specify which traits are
 required when constructing `NonExhaustive<>` from this enum and are then usable with it.
 
 The type describes which traits are required using the [`InterfaceType`] trait.
@@ -135,7 +135,7 @@ This means that only Debug/PartialEq are usable/required.<br>
 Example3:`interface="CloneEqInterface"`.
 This means that only Debug/Clone/Eq/PartialEq are usable/required.<br>
 
-The `*Interface` types from the examples come from the 
+The `*Interface` types from the examples come from the
 `abi_stable::erased_types::interfaces` module.
 
 
@@ -159,7 +159,7 @@ Example:`assert_nonexhaustive("Foo<u8>","Foo<RVec<()>>")`<br>
 
 # `serde` support
 
-`NonExhaustive<Enum,Storage,Interface>` only implements serde::{Serialize,Deserialize} 
+`NonExhaustive<Enum,Storage,Interface>` only implements serde::{Serialize,Deserialize}
 if Interface allows them in its [`InterfaceType`] implementation,
 and also implements the [`SerializeEnum`] and [`DeserializeEnum`] traits.
 
@@ -167,45 +167,44 @@ and also implements the [`SerializeEnum`] and [`DeserializeEnum`] traits.
 
 This defines a nonexhaustive enum and demonstrates how it is (de)serialized.
 
-For a more realistic example you can look at the 
+For a more realistic example you can look at the
 "examples/2_nonexhaustive/interface" crate in the repository for this crate.
 
 ```
 
 use abi_stable::{
-    StableAbi,
-    rtry,
-    sabi_extern_fn,
-    external_types::{RawValueBox,RawValueRef},
-    nonexhaustive_enum::{NonExhaustive,SerializeEnum,DeserializeEnum},
+    external_types::{RawValueBox, RawValueRef},
+    nonexhaustive_enum::{DeserializeEnum, NonExhaustive, SerializeEnum},
     prefix_type::{PrefixTypeTrait, WithMetadata},
-    std_types::{RBoxError,RString,RStr,RResult,ROk,RErr},
+    rtry, sabi_extern_fn,
+    std_types::{RBoxError, RErr, ROk, RResult, RStr, RString},
     traits::IntoReprC,
+    StableAbi,
 };
 
-use serde::{Deserialize,Serialize};
+use serde::{Deserialize, Serialize};
 
 #[repr(u8)]
-#[derive(StableAbi,Debug,Clone,PartialEq,Deserialize,Serialize)]
+#[derive(StableAbi, Debug, Clone, PartialEq, Deserialize, Serialize)]
 #[sabi(kind(WithNonExhaustive(
-    // Determines the maximum size of this enum in semver compatible versions.
-    size="[usize;10]",
-    // Determines the traits that are required when wrapping this enum in NonExhaustive,
-    // and are then available with it.
-    traits(Debug,Clone,PartialEq,Serialize,Deserialize),
+// Determines the maximum size of this enum in semver compatible versions.
+size="[usize;10]",
+// Determines the traits that are required when wrapping this enum in NonExhaustive,
+// and are then available with it.
+traits(Debug,Clone,PartialEq,Serialize,Deserialize),
 )))]
 // The `#[sabi(with_constructor)]` helper attribute here generates constructor functions
 // that look take the fields of the variant as parameters and return a `ValidTag_NE`.
-#[sabi(with_constructor)] 
-pub enum ValidTag{
+#[sabi(with_constructor)]
+pub enum ValidTag {
     #[doc(hidden)]
     __NonExhaustive,
     Foo,
     Bar,
-    Tag{
-        name:RString,
-        tag:RString,
-    }
+    Tag {
+        name: RString,
+        tag: RString,
+    },
 }
 
 /*
@@ -222,30 +221,24 @@ pub type ValidTag_NE=
 impl SerializeEnum<ValidTag_NE> for ValidTag_Interface {
     /// A type that `ValidTag_NE` is converted into(inside `SerializeEnum::serialize_enum`),
     /// and then serialized.
-    type Proxy=RawValueBox;
+    type Proxy = RawValueBox;
 
-    fn serialize_enum(this:&ValidTag_NE) -> Result<RawValueBox, RBoxError>{
-        Module::VALUE
-            .serialize_tag()(this)
-            .into_result()
-        
+    fn serialize_enum(this: &ValidTag_NE) -> Result<RawValueBox, RBoxError> {
+        Module::VALUE.serialize_tag()(this).into_result()
     }
 }
 
 /// This describes how the enum is deserialized.
-impl<'a> DeserializeEnum<'a,ValidTag_NE> for ValidTag_Interface{
+impl<'a> DeserializeEnum<'a, ValidTag_NE> for ValidTag_Interface {
     /// A type that is deserialized,
     /// and then converted into `ValidTag_NE` inside `DeserializeEnum::deserialize_enum`.
-    type Proxy=RawValueRef<'a>;
+    type Proxy = RawValueRef<'a>;
 
-    fn deserialize_enum(s: RawValueRef<'a>) -> Result<ValidTag_NE, RBoxError>{
-        Module::VALUE
-            .deserialize_tag()(s.get_rstr())
-            .into_result()
+    fn deserialize_enum(s: RawValueRef<'a>) -> Result<ValidTag_NE, RBoxError> {
+        Module::VALUE.deserialize_tag()(s.get_rstr()).into_result()
     }
 }
 
-
 # fn main(){
 
 assert_eq!(
@@ -259,17 +252,18 @@ assert_eq!(
 );
 
 assert_eq!(
-    serde_json::from_str::<ValidTag_NE>(r#"
-        {"Tag":{
-            "name":"what",
-            "tag":"the"
-        }}
-    "#).unwrap(),
-    ValidTag::Tag_NE("what".into(),"the".into())
+    serde_json::from_str::<ValidTag_NE>(
+        r#"
+    {"Tag":{
+        "name":"what",
+        "tag":"the"
+    }}
+"#
+    )
+    .unwrap(),
+    ValidTag::Tag_NE("what".into(), "the".into())
 );
 
-
-
 assert_eq!(
     &serde_json::to_string(&ValidTag::Foo_NE()).unwrap(),
     r#""Foo""#,
@@ -283,32 +277,34 @@ assert_eq!(
 # }
 
 // In this struct:
-// 
+//
 // - `#[sabi(kind(Prefix))]`
 // Declares this type as being a prefix-type, generating both of these types:
-// 
-//     - Module_Prefix`: A struct with the fields up to (and including) the field with the 
+//
+//     - Module_Prefix`: A struct with the fields up to (and including) the field with the
 //     `#[sabi(last_prefix_field)]` attribute.
-// 
+//
 //     - Module_Ref`: An ffi-safe pointer to a `Module`,with methods to get `Module`'s fields.
-// 
-// - `#[sabi(missing_field(panic))]` 
-//     makes the field accessors of `ModuleRef` panic when attempting to 
+//
+// - `#[sabi(missing_field(panic))]`
+//     makes the field accessors of `ModuleRef` panic when attempting to
 //     access nonexistent fields instead of the default of returning an Option<FieldType>.
-// 
+//
 #[repr(C)]
-#[derive(StableAbi)] 
+#[derive(StableAbi)]
 #[sabi(kind(Prefix))]
 #[sabi(missing_field(panic))]
-pub struct Module{
-    pub serialize_tag:extern "C" fn(&ValidTag_NE)->RResult<RawValueBox,RBoxError>,
-    
+pub struct Module {
+    pub serialize_tag:
+        extern "C" fn(&ValidTag_NE) -> RResult<RawValueBox, RBoxError>,
+
     /// `#[sabi(last_prefix_field)]`means that it is the last field in the struct
     /// that was defined in the first compatible version of the library
     /// (0.1.0, 0.2.0, 0.3.0, 1.0.0, 2.0.0 ,etc),
     /// requiring new fields to always be added below preexisting ones.
     #[sabi(last_prefix_field)]
-    pub deserialize_tag:extern "C" fn(s:RStr<'_>)->RResult<ValidTag_NE,RBoxError>,
+    pub deserialize_tag:
+        extern "C" fn(s: RStr<'_>) -> RResult<ValidTag_NE, RBoxError>,
 }
 
 // This is how you can construct `Module` in a way that allows it to become generic later.
@@ -317,7 +313,7 @@ impl Module {
     //
     // StaticRef represents a reference to data that lives forever,
     // but is not necessarily `'static` according to the type system.
-    // 
+    //
     // StaticRef not necessary in this case, it's more useful with generic types..
     abi_stable::staticref!(const TMP0: WithMetadata<Self> = WithMetadata::new(
         PrefixTypeTrait::METADATA,
@@ -327,7 +323,7 @@ impl Module {
         },
     ));
 
-    const VALUE: Module_Ref = Module_Ref( Self::TMP0.as_prefix() );
+    const VALUE: Module_Ref = Module_Ref(Self::TMP0.as_prefix());
 }
 
 /////////////////////////////////////////////////////////////////////////////////////////
@@ -335,28 +331,25 @@ impl Module {
 /////////////////////////////////////////////////////////////////////////////////////////
 
 #[sabi_extern_fn]
-pub fn serialize_tag(enum_:&ValidTag_NE)->RResult<RawValueBox,RBoxError>{
-    let enum_=rtry!( enum_.as_enum().into_c() );
-    
+pub fn serialize_tag(enum_: &ValidTag_NE) -> RResult<RawValueBox, RBoxError> {
+    let enum_ = rtry!(enum_.as_enum().into_c());
+
     match serde_json::to_string(&enum_) {
-        Ok(v)=>{
-            RawValueBox::try_from_string(v)
-                .map_err(RBoxError::new)
-                .into_c()
-        }
-        Err(e)=>RErr(RBoxError::new(e)),
+        Ok(v) => RawValueBox::try_from_string(v)
+            .map_err(RBoxError::new)
+            .into_c(),
+        Err(e) => RErr(RBoxError::new(e)),
     }
 }
 
 #[sabi_extern_fn]
-pub fn deserialize_tag(s:RStr<'_>)->RResult<ValidTag_NE,RBoxError>{
+pub fn deserialize_tag(s: RStr<'_>) -> RResult<ValidTag_NE, RBoxError> {
     match serde_json::from_str::<ValidTag>(s.into()) {
         Ok(x) => ROk(NonExhaustive::new(x)),
         Err(e) => RErr(RBoxError::new(e)),
     }
 }
 
-
 ```
 
 
@@ -370,25 +363,24 @@ because one of the variant contains a generic type.
 
 ```
 use abi_stable::{
-    StableAbi,
-    nonexhaustive_enum::{NonExhaustiveFor,NonExhaustive},
-    std_types::{RBox,RString},
+    nonexhaustive_enum::{NonExhaustive, NonExhaustiveFor},
     sabi_trait,
+    std_types::{RBox, RString},
+    StableAbi,
 };
 
 use std::{
     cmp::PartialEq,
-    fmt::{self,Debug,Display},
+    fmt::{self, Debug, Display},
 };
 
-
 #[repr(u8)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
+#[derive(StableAbi, Debug, Clone, PartialEq)]
 #[sabi(kind(WithNonExhaustive(
-    size="[usize;3]",
-    traits(Debug,Display,Clone,PartialEq),
+    size = "[usize;3]",
+    traits(Debug, Display, Clone, PartialEq),
 )))]
-pub enum Message<T>{
+pub enum Message<T> {
     #[doc(hidden)]
     __NonExhaustive,
     SaysHello,
@@ -396,75 +388,69 @@ pub enum Message<T>{
 
     #[sabi(with_boxed_constructor)]
     Custom(RBox<T>),
-    
+
     ////////////////////////////////////////
     // Available since 1.1
     ////////////////////////////////////////
     #[sabi(with_boxed_constructor)]
-    SaysThankYou(RBox<SaysThankYou>)
-    
+    SaysThankYou(RBox<SaysThankYou>),
 }
 
-
 impl<T> Display for Message<T>
 where
-    T:Display
+    T: Display,
 {
-    fn fmt(&self,f:&mut fmt::Formatter<'_>)->fmt::Result{
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match self {
-            Message::__NonExhaustive=>unreachable!(),
-            Message::SaysHello=>write!(f,"Hello!"),
-            Message::SaysGoodbye=>write!(f,"Goodbye!"),
-            Message::Custom(custom)=>Display::fmt(&**custom,f),
-            Message::SaysThankYou(x)=>writeln!(f,"Thank you,{}!",x.to),
+            Message::__NonExhaustive => unreachable!(),
+            Message::SaysHello => write!(f, "Hello!"),
+            Message::SaysGoodbye => write!(f, "Goodbye!"),
+            Message::Custom(custom) => Display::fmt(&**custom, f),
+            Message::SaysThankYou(x) => writeln!(f, "Thank you,{}!", x.to),
         }
     }
 }
 
-
 // Only available since 1.1
 #[repr(C)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
-pub struct SaysThankYou{
-    to:RString,
+#[derive(StableAbi, Debug, Clone, PartialEq)]
+pub struct SaysThankYou {
+    to: RString,
 }
 
 # fn main(){
- 
-// Constructing Message::Custom wrapped in a NonExhaustive 
-{
-    let custom_message:Message_NE<RString>=
-        Message::Custom_NE("Hello".into());
 
-    let custom_message_desugar:Message_NE<RString>={
-        let x=RBox::new("Hello".into());
-        let x=Message::Custom(x);
+// Constructing Message::Custom wrapped in a NonExhaustive
+{
+    let custom_message: Message_NE<RString> = Message::Custom_NE("Hello".into());
+
+    let custom_message_desugar: Message_NE<RString> = {
+        let x = RBox::new("Hello".into());
+        let x = Message::Custom(x);
         NonExhaustive::new(x)
     };
 
-    assert_eq!(custom_message,custom_message_desugar);
+    assert_eq!(custom_message, custom_message_desugar);
 }
 
-
-// Constructing Message::SaysThankYou wrapped in a NonExhaustive 
+// Constructing Message::SaysThankYou wrapped in a NonExhaustive
 // This variant is only available since 1.1
 {
-    let says_thank_you:Message_NE<RString>=
-        Message::SaysThankYou_NE(SaysThankYou{
-            to:"Hello".into(),
-        });
+    let says_thank_you: Message_NE<RString> =
+        Message::SaysThankYou_NE(SaysThankYou { to: "Hello".into() });
 
-    let says_thank_you_desugar:Message_NE<RString>={
-        let x=SaysThankYou{to:"Hello".into()};
-        let x=Message::SaysThankYou(RBox::new(x));
+    let says_thank_you_desugar: Message_NE<RString> = {
+        let x = SaysThankYou { to: "Hello".into() };
+        let x = Message::SaysThankYou(RBox::new(x));
         NonExhaustive::new(x)
     };
 
-    assert_eq!(says_thank_you,says_thank_you_desugar);
+    assert_eq!(says_thank_you, says_thank_you_desugar);
 }
 
 # }
 
+
 ```
 
 
@@ -476,107 +462,96 @@ This example shows how one can use RSmallBox to define a generic nonexhausitve e
 ```
 
 use abi_stable::{
-    sabi_types::RSmallBox,
-    std_types::{RString,RVec},
     reexports::SelfOps,
+    sabi_types::RSmallBox,
+    std_types::{RString, RVec},
     StableAbi,
 };
 
 #[repr(u8)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
+#[derive(StableAbi, Debug, Clone, PartialEq)]
 #[sabi(kind(WithNonExhaustive(
-    // Determines the maximum size of this enum in semver compatible versions.
-    // This is 11 usize large because:
-    //    - The enum discriminant occupies 1 usize(because the enum is usize aligned).
-    //    - RSmallBox<T,[usize;8]>: is 10 usize large
-    size="[usize;11]",
-    // Determines the traits that are required when wrapping this enum in NonExhaustive,
-    // and are then available with it.
-    traits(Debug,Clone,PartialEq),
+// Determines the maximum size of this enum in semver compatible versions.
+// This is 11 usize large because:
+//    - The enum discriminant occupies 1 usize(because the enum is usize aligned).
+//    - RSmallBox<T,[usize;8]>: is 10 usize large
+size="[usize;11]",
+// Determines the traits that are required when wrapping this enum in NonExhaustive,
+// and are then available with it.
+traits(Debug,Clone,PartialEq),
 )))]
 #[sabi(with_constructor)]
-pub enum SomeEnum<T>{
+pub enum SomeEnum<T> {
     #[doc(hidden)]
     __NonExhaustive,
     Foo,
     Bar,
-    Crash{
-        reason:RString,
-        animal:RString,
+    Crash {
+        reason: RString,
+        animal: RString,
     },
     // This variant was added in a newer (compatible) version of the library.
     #[sabi(with_boxed_constructor)]
-    Other(RSmallBox<T,[usize;8]>)
+    Other(RSmallBox<T, [usize; 8]>),
 }
 
-impl<T> SomeEnum<T>{
-    pub fn is_inline(&self)->bool{
+impl<T> SomeEnum<T> {
+    pub fn is_inline(&self) -> bool {
         match self {
-            SomeEnum::__NonExhaustive=>true,
-            SomeEnum::Foo=>true,
-            SomeEnum::Bar=>true,
-            SomeEnum::Crash{..}=>true,
-            SomeEnum::Other(rsbox)=>RSmallBox::is_inline(rsbox),
+            SomeEnum::__NonExhaustive => true,
+            SomeEnum::Foo => true,
+            SomeEnum::Bar => true,
+            SomeEnum::Crash { .. } => true,
+            SomeEnum::Other(rsbox) => RSmallBox::is_inline(rsbox),
         }
     }
 
-    pub fn is_heap_allocated(&self)->bool{
+    pub fn is_heap_allocated(&self) -> bool {
         !self.is_inline()
     }
-
 }
 
-
 #[repr(C)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
-pub struct FullName{
-    pub name:RString,
-    pub surname:RString,
+#[derive(StableAbi, Debug, Clone, PartialEq)]
+pub struct FullName {
+    pub name: RString,
+    pub surname: RString,
 }
 
-
 /// A way to represent a frozen `Vec<Vec<T>>`.
 ///
 /// This example just constructs NestedVec directly,
 /// realistically it would be constructed in an associated function of NestedVec.
 #[repr(C)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
-pub struct NestedVec<T>{
-    indices:RVec<usize>,
-    nested:RVec<T>,
-    dummy_field:u32,
+#[derive(StableAbi, Debug, Clone, PartialEq)]
+pub struct NestedVec<T> {
+    indices: RVec<usize>,
+    nested: RVec<T>,
+    dummy_field: u32,
 }
 
-
 # fn main(){
 
-let crash=SomeEnum::<()>::Crash_NE("No reason".into(),"Bandi____".into());
+let crash = SomeEnum::<()>::Crash_NE("No reason".into(), "Bandi____".into());
 
-let other_fullname=
-    SomeEnum::Other_NE(FullName{ name:"R__e".into(), surname:"L_____e".into() });
+let other_fullname = SomeEnum::Other_NE(FullName {
+    name: "R__e".into(),
+    surname: "L_____e".into(),
+});
 
-let other_nestedlist={
-    let nestedlist=NestedVec{
-        indices:vec![0,2,3,5].into(),
+let other_nestedlist = {
+    let nestedlist = NestedVec {
+        indices: vec![0, 2, 3, 5].into(),
         // Each line here is a nested list.
-        nested:vec![
-            false,false,
-            true,
-            true,false,
-            true,true,true,
-        ].into(),
-        dummy_field:0,
+        nested: vec![false, false, true, true, false, true, true, true].into(),
+        dummy_field: 0,
     };
     SomeEnum::Other_NE(nestedlist)
 };
 
-
-
-
-assert!( crash.as_enum().unwrap().is_inline() );
-assert!( other_fullname.as_enum().unwrap().is_inline() );
-assert!( other_nestedlist.as_enum().unwrap().is_heap_allocated() );
-
+assert!(crash.as_enum().unwrap().is_inline());
+assert!(other_fullname.as_enum().unwrap().is_inline());
+assert!(other_nestedlist.as_enum().unwrap().is_heap_allocated());
 
 # }
 
@@ -591,190 +566,192 @@ Say that we want to define a "private" enum
 used internally to send information between instances of the same library,
 of potentially different (compatible) versions.
 
-If one of the variants from newer versions are sent into a library/binary 
+If one of the variants from newer versions are sent into a library/binary
 that has a previous version of `Event`,
-`Event_NE` (an alias for NonExhaustive wrapping an Event) 
+`Event_NE` (an alias for NonExhaustive wrapping an Event)
 won't be convertible back into `Event`.
 
 ```
 use abi_stable::{
-    StableAbi,
-    nonexhaustive_enum::{NonExhaustiveFor,NonExhaustive},
-    std_types::{RString,RArc},
+    nonexhaustive_enum::{NonExhaustive, NonExhaustiveFor},
     sabi_trait,
+    std_types::{RArc, RString},
+    StableAbi,
 };
 
+#[doc(hidden)]
+#[repr(C)]
+#[derive(StableAbi, Debug, Clone, Copy, PartialEq)]
+pub struct ObjectId(pub usize);
 
 #[doc(hidden)]
 #[repr(C)]
-#[derive(StableAbi,Debug,Clone,Copy,PartialEq)]
-pub struct ObjectId(
-    pub usize
-);
-
-#[doc(hidden)]
-#[repr(C)]
-#[derive(StableAbi,Debug,Clone,Copy,PartialEq)]
-pub struct GroupId(
-    pub usize
-);
-
+#[derive(StableAbi, Debug, Clone, Copy, PartialEq)]
+pub struct GroupId(pub usize);
 
 #[repr(u8)]
-#[derive(StableAbi,Debug,Clone,PartialEq)]
+#[derive(StableAbi, Debug, Clone, PartialEq)]
 #[sabi(kind(WithNonExhaustive(
-    size="[usize;8]",
-    traits(Debug,Clone,PartialEq),
+    size = "[usize;8]",
+    traits(Debug, Clone, PartialEq),
 )))]
 #[sabi(with_constructor)]
-pub enum Event{
+pub enum Event {
     #[doc(hidden)]
     __NonExhaustive,
-    CreatedInstance{
-        object_id:ObjectId,
+    CreatedInstance {
+        object_id: ObjectId,
     },
-    RemovedInstance{
-        object_id:ObjectId,
+    RemovedInstance {
+        object_id: ObjectId,
     },
-    
+
     /////////////////
     // Added in 1.1
     /////////////////
-    CreatedGroup{
-        name:RString,
-        group_id:GroupId,
+    CreatedGroup {
+        name: RString,
+        group_id: GroupId,
     },
-    RemovedGroup{
-        name:RString,
-        group_id:GroupId,
+    RemovedGroup {
+        name: RString,
+        group_id: GroupId,
     },
-    AssociatedWithGroup{
-        object_id:ObjectId,
-        group_id:GroupId,
+    AssociatedWithGroup {
+        object_id: ObjectId,
+        group_id: GroupId,
     },
-    
+
     /////////////////
     // Added in 1.2
     /////////////////
-    RemovedAssociationWithGroup{
-        object_id:ObjectId,
-        group_id:GroupId,
+    RemovedAssociationWithGroup {
+        object_id: ObjectId,
+        group_id: GroupId,
     },
     #[sabi(with_boxed_constructor)]
-    DummyVariant{
-        pointer:RArc<()>,
+    DummyVariant {
+        pointer: RArc<()>,
     },
 }
 
-let objectid_0=ObjectId(0);
-let objectid_1=ObjectId(1);
+let objectid_0 = ObjectId(0);
+let objectid_1 = ObjectId(1);
 
-let groupid_0=GroupId(0);
-let groupid_1=GroupId(0);
+let groupid_0 = GroupId(0);
+let groupid_1 = GroupId(0);
 
 // Constructing a Event::CreatedInstance wrapped in a NonExhaustive
 {
-    let from_ne_constructor:Event_NE=
-        Event::CreatedInstance_NE(objectid_0);
-    let regular={
-        let ev=Event::CreatedInstance{object_id:objectid_0};
+    let from_ne_constructor: Event_NE = Event::CreatedInstance_NE(objectid_0);
+    let regular = {
+        let ev = Event::CreatedInstance {
+            object_id: objectid_0,
+        };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 // Constructing a Event::RemovedInstance wrapped in a NonExhaustive
 {
-    let from_ne_constructor=Event::RemovedInstance_NE(objectid_0);
-    let regular={
-        let ev=Event::RemovedInstance{object_id:objectid_0};
+    let from_ne_constructor = Event::RemovedInstance_NE(objectid_0);
+    let regular = {
+        let ev = Event::RemovedInstance {
+            object_id: objectid_0,
+        };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 // Constructing a Event::RemovedInstance wrapped in a NonExhaustive
 {
-    let from_ne_constructor=Event::RemovedInstance_NE(objectid_0);
-    let regular={
-        let ev=Event::RemovedInstance{object_id:objectid_0};
+    let from_ne_constructor = Event::RemovedInstance_NE(objectid_0);
+    let regular = {
+        let ev = Event::RemovedInstance {
+            object_id: objectid_0,
+        };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 // Constructing a Event::CreatedGroup wrapped in a NonExhaustive
 // This is only available from 1.1
 {
-    let from_ne_constructor=Event::CreatedGroup_NE("hello".into(),groupid_0);
-    let regular={
-        let ev=Event::CreatedGroup{name:"hello".into(),group_id:groupid_0};
+    let from_ne_constructor = Event::CreatedGroup_NE("hello".into(), groupid_0);
+    let regular = {
+        let ev = Event::CreatedGroup {
+            name: "hello".into(),
+            group_id: groupid_0,
+        };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 // Constructing a Event::RemovedGroup wrapped in a NonExhaustive
 // This is only available from 1.1
 {
-    let from_ne_constructor=Event::RemovedGroup_NE("hello".into(),groupid_0);
-    let regular={
-        let ev=Event::RemovedGroup{name:"hello".into(),group_id:groupid_0};
+    let from_ne_constructor = Event::RemovedGroup_NE("hello".into(), groupid_0);
+    let regular = {
+        let ev = Event::RemovedGroup {
+            name: "hello".into(),
+            group_id: groupid_0,
+        };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
-
 // Constructing a Event::AssociatedWithGroup wrapped in a NonExhaustive
 // This is only available from 1.1
 {
-    let from_ne_constructor=Event::AssociatedWithGroup_NE(objectid_0,groupid_0);
-    let regular={
-        let ev=Event::AssociatedWithGroup{
-            object_id:objectid_0,
-            group_id:groupid_0,
+    let from_ne_constructor = Event::AssociatedWithGroup_NE(objectid_0, groupid_0);
+    let regular = {
+        let ev = Event::AssociatedWithGroup {
+            object_id: objectid_0,
+            group_id: groupid_0,
         };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
-
 // Constructing a Event::RemovedAssociationWithGroup wrapped in a NonExhaustive
 // This is only available from 1.2
 {
-    let from_ne_constructor=Event::RemovedAssociationWithGroup_NE(objectid_0,groupid_0);
-    let regular={
-        let ev=Event::RemovedAssociationWithGroup{
-            object_id:objectid_0,
-            group_id:groupid_0,
+    let from_ne_constructor =
+        Event::RemovedAssociationWithGroup_NE(objectid_0, groupid_0);
+    let regular = {
+        let ev = Event::RemovedAssociationWithGroup {
+            object_id: objectid_0,
+            group_id: groupid_0,
         };
         NonExhaustive::new(ev)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 // Constructing a Event::DummyVariant wrapped in a NonExhaustive
 // This is only available from 1.2
 {
-    let from_ne_constructor=Event::DummyVariant_NE(());
-    let regular={
-        let x=RArc::new(());
-        let x=Event::DummyVariant{
-            pointer:x
-        };
+    let from_ne_constructor = Event::DummyVariant_NE(());
+    let regular = {
+        let x = RArc::new(());
+        let x = Event::DummyVariant { pointer: x };
         NonExhaustive::new(x)
     };
 
-    assert_eq!(from_ne_constructor,regular);
+    assert_eq!(from_ne_constructor, regular);
 }
 
 ```
@@ -785,4 +762,4 @@ let groupid_1=GroupId(0);
 [`SerializeEnum`]: ../../nonexhaustive_enum/trait.SerializeEnum.html
 [`DeserializeEnum`]: ../../nonexhaustive_enum/trait.DeserializeEnum.html
 
-*/
\ No newline at end of file
+*/
